from deprecated import deprecated

DEPRECATION_VERSION='0.3.0'
DEPRECATION_REASON='The QualysGraphClient has been deprecated since it depends on matplotlib->pillow->zlib, which breaks portability.'

class QualysGraphClient:
    @staticmethod
    @deprecated(version=DEPRECATION_VERSION, reason=DEPRECATION_REASON)
    def render_basic_report_data_as_graph(data: str):
        raise Exception(DEPRECATION_REASON)

    @staticmethod
    @deprecated(version=DEPRECATION_VERSION, reason=DEPRECATION_REASON)
    def render_basic_report_data_as_graph_v2(data: str):
        raise Exception(DEPRECATION_REASON)
